# rocket

`rockettp` is a Python library for ..........

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `rockettp`.

```bash
pip install rockettp
```

## Usage

```python
import rockettp

# returns 'words'
rockettp.module_name('word')

# returns 'geese'
rockettp.module_name('goose')

# returns 'phenomenon'
rockettp.module_name('phenomena')
```

## License
[MIT](https://choosealicense.com/licenses/mit/)